/* ########################################################################

				config.h

   File: xc_conf.h
   Path: /home/fournigault/c/X11/xcoral-2.31/xc_conf.h
   Description: 
   Created: Fri Jan 27 10:55:13 MET 1995
   Author: Lionel Fournigault
   Modified: Fri Jan 27 10:55:14 MET 1995
   Last maintained by: Lionel Fournigault

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Lionel Fournigault

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */


#ifndef _XC_CONF_H_
#define _XC_CONF_H_

/*
 *	Les Fontes
 */

#define TEXT_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
/*#define TEXT_FONT "-misc-fixed-medium-r-normal--13-120-75-75-c-70-iso8859-1" */

#define MENU_FONT   "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define B_FONT     "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define WBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define DBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define FSBOX_FONT "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define LBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define MBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
#define TBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"

/*
#define TEXT_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define MENU_FONT   "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"

#define B_FONT 	   "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define WBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define DBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define FSBOX_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define LBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
#define MBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"

#define MENU_FONT   "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define TEXT_FONT "-adobe-courier-medium-r-normal--14-140-75-75-m-90-iso8859-1"
#define B_FONT     "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define WBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define DBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define FSBOX_FONT "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define LBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
#define MBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
*/


/* Dark background (default) */
/* #define COLOR_TEXT_BG		"midnightblue" */
#define COLOR_TEXT_BG		"ivory"
/* #define COLOR_TEXT_BG		"honeydew" */
/* #define COLOR_TEXT_FG		"lemonchiffon" */
#define COLOR_TEXT_FG		"black"

/* Light background */
/*
#define COLOR_TEXT_BG		"oldlace"
#define COLOR_TEXT_FG		"black"
*/

#define COLOR_MENU_BG		"gray60"  /*"slategray"*/
#define COLOR_MENU_FG		"lemonchiffon"
/* #define COLOR_MENU_FG		"black" */
#define COLOR_CONTROL_BG	"gray60"  /*"slategray"*/
#define COLOR_CONTROL_FG	"lemonchiffon"
/* #define COLOR_CONTROL_FG	"black" */

/*
 *	Mono
 */
#define BW_TEXT_BG		"black"
#define BW_TEXT_FG		"white"
#define BW_MENU_BG		"white"
#define BW_MENU_FG		"black"
#define BW_CONTROL_BG		"white"
#define BW_CONTROL_FG		"black"

#define APP_DEFAULT		"/usr/lib/X11/app-defaults"

#endif  /* _XC_CONF_H_ */
